@@ -76,7 +76,7 @@ class MYSQLExporter(Result):
             print "Not saving to mysql database: %s" %e
 
         if self.args.get_only_ff:
-            self.save(aq, [ 2, obj[0][0] ])
+            self.save(aq, [ 2, obj[0][0][0] ])
             obj=[obj[1], obj[2]]
         else:
             self.save(aq, obj[0])
@@ -212,7 +212,7 @@ class ResultsGenerator(object):
 
                 try:
                     for friend_id in user_[2]['ids']:
-                        myfriends.append([id_, user_[0]['id']])
+                        myfriends.append([id_, friend_id])
                 except Exception, e:
                     print(e)
 
